@@ -104,6 +104,8 @@ pub struct RenderPass {
 
 impl RenderPass {
     /// Creates a new render pass to render a egui UI.
+    ///
+    /// If the format passed is not a *Srgb format, the shader will automatically convert to sRGB colors in the shader.
     pub fn new(
         device: &wgpu::Device,
         output_format: wgpu::TextureFormat,
@@ -172,10 +174,7 @@ impl RenderPass {
                     wgpu::BindGroupLayoutEntry {
                         binding: 1,
                         visibility: wgpu::ShaderStages::FRAGMENT,
-                        ty: wgpu::BindingType::Sampler {
-                            filtering: true,
-                            comparison: false,
-                        },
+                        ty: wgpu::BindingType::Sampler(wgpu::SamplerBindingType::Filtering),
                         count: None,
                     },
                 ],
@@ -191,10 +190,10 @@ impl RenderPass {
             label: Some("egui_pipeline"),
             layout: Some(&pipeline_layout),
             vertex: wgpu::VertexState {
-                entry_point: if cfg!(feature = "web") {
-                    "vs_web_main"
-                } else {
+                entry_point: if output_format.describe().srgb {
                     "vs_main"
+                } else {
+                    "vs_conv_main"
                 },
                 module: &module,
                 buffers: &[wgpu::VertexBufferLayout {
@@ -208,7 +207,7 @@ impl RenderPass {
             },
             primitive: wgpu::PrimitiveState {
                 topology: wgpu::PrimitiveTopology::TriangleList,
-                clamp_depth: false,
+                unclipped_depth: false,
                 conservative: false,
                 cull_mode: None,
                 front_face: wgpu::FrontFace::default(),
@@ -242,6 +241,7 @@ impl RenderPass {
                     write_mask: wgpu::ColorWrites::ALL,
                 }],
             }),
+            multiview: None,
         });
 
         Self {
@@ -261,7 +261,7 @@ impl RenderPass {
 
     /// Executes the egui render pass. When `clear_on_draw` is set, the output target will get cleared before writing to it.
     pub fn execute(
-        &mut self,
+        &self,
         encoder: &mut wgpu::CommandEncoder,
         color_attachment: &wgpu::TextureView,
         paint_jobs: &[egui::paint::ClippedMesh],
@@ -274,7 +274,7 @@ impl RenderPass {
             wgpu::LoadOp::Load
         };
 
-        let mut pass = encoder.begin_render_pass(&wgpu::RenderPassDescriptor {
+        let mut rpass = encoder.begin_render_pass(&wgpu::RenderPassDescriptor {
             color_attachments: &[wgpu::RenderPassColorAttachment {
                 view: color_attachment,
                 resolve_target: None,
@@ -286,10 +286,25 @@ impl RenderPass {
             depth_stencil_attachment: None,
             label: Some("egui main render pass"),
         });
-        pass.push_debug_group("egui_pass");
-        pass.set_pipeline(&self.render_pipeline);
+        rpass.push_debug_group("egui_pass");
 
-        pass.set_bind_group(0, &self.uniform_bind_group, &[]);
+        self.execute_with_renderpass(&mut rpass, paint_jobs, screen_descriptor)?;
+
+        rpass.pop_debug_group();
+
+        Ok(())
+    }
+
+    /// Executes the egui render pass onto an existing wgpu renderpass.
+    pub fn execute_with_renderpass<'rpass>(
+        &'rpass self,
+        rpass: &mut wgpu::RenderPass<'rpass>,
+        paint_jobs: &[egui::paint::ClippedMesh],
+        screen_descriptor: &ScreenDescriptor,
+    ) -> Result<(), BackendError> {
+        rpass.set_pipeline(&self.render_pipeline);
+
+        rpass.set_bind_group(0, &self.uniform_bind_group, &[]);
 
         let scale_factor = screen_descriptor.scale_factor;
         let physical_width = screen_descriptor.physical_width;
@@ -332,18 +347,16 @@ impl RenderPass {
                     continue;
                 }
 
-                pass.set_scissor_rect(x, y, width, height);
+                rpass.set_scissor_rect(x, y, width, height);
             }
             let bind_group = self.get_texture_bind_group(mesh.texture_id)?;
-            pass.set_bind_group(1, bind_group, &[]);
+            rpass.set_bind_group(1, bind_group, &[]);
 
-            pass.set_index_buffer(index_buffer.buffer.slice(..), wgpu::IndexFormat::Uint32);
-            pass.set_vertex_buffer(0, vertex_buffer.buffer.slice(..));
-            pass.draw_indexed(0..mesh.indices.len() as u32, 0, 0..1);
+            rpass.set_index_buffer(index_buffer.buffer.slice(..), wgpu::IndexFormat::Uint32);
+            rpass.set_vertex_buffer(0, vertex_buffer.buffer.slice(..));
+            rpass.draw_indexed(0..mesh.indices.len() as u32, 0, 0..1);
         }
 
-        pass.pop_debug_group();
-
         Ok(())
     }
 
@@ -498,12 +511,60 @@ impl RenderPass {
         device: &wgpu::Device,
         texture: &wgpu::Texture,
         texture_filter: wgpu::FilterMode,
+    ) -> egui::TextureId {
+        self.egui_texture_from_wgpu_texture_with_sampler_options(
+            device,
+            texture,
+            wgpu::SamplerDescriptor {
+                label: Some(format!("{}_texture_sampler", self.next_user_texture_id).as_str()),
+                mag_filter: texture_filter,
+                min_filter: texture_filter,
+                ..Default::default()
+            },
+        )
+    }
+
+    /// Registers a `wgpu::Texture` with an existing `egui::TextureId`.
+    ///
+    /// This enables applications to reuse `TextureId`s.
+    pub fn update_egui_texture_from_wgpu_texture(
+        &mut self,
+        device: &wgpu::Device,
+        texture: &wgpu::Texture,
+        texture_filter: wgpu::FilterMode,
+        id: egui::TextureId,
+    ) -> Result<(), BackendError> {
+        self.update_egui_texture_from_wgpu_texture_with_sampler_options(
+            device,
+            texture,
+            wgpu::SamplerDescriptor {
+                label: Some(format!("{}_texture_sampler", self.next_user_texture_id).as_str()),
+                mag_filter: texture_filter,
+                min_filter: texture_filter,
+                ..Default::default()
+            },
+            id,
+        )
+    }
+
+    /// Registers a `wgpu::Texture` with a `egui::TextureId` while also accepting custom
+    /// `wgpu::SamplerDescriptor` options.
+    ///
+    /// This allows applications to specify individual minification/magnification filters as well as
+    /// custom mipmap and tiling options.
+    ///
+    /// The `Texture` must have the format `TextureFormat::Rgba8UnormSrgb` and usage
+    /// `TextureUsage::SAMPLED`. Any compare function supplied in the `SamplerDescriptor` will be
+    /// ignored.
+    pub fn egui_texture_from_wgpu_texture_with_sampler_options(
+        &mut self,
+        device: &wgpu::Device,
+        texture: &wgpu::Texture,
+        sampler_descriptor: wgpu::SamplerDescriptor,
     ) -> egui::TextureId {
         let sampler = device.create_sampler(&wgpu::SamplerDescriptor {
-            label: Some(format!("{}_texture_sampler", self.next_user_texture_id).as_str()),
-            mag_filter: texture_filter,
-            min_filter: texture_filter,
-            ..Default::default()
+            compare: None,
+            ..sampler_descriptor
         });
 
         // We've bound it here, so that we don't add it as a pending texture.
@@ -530,14 +591,15 @@ impl RenderPass {
         texture_id
     }
 
-    /// Registers a `wgpu::Texture` with an existing `egui::TextureId`.
+    /// Registers a `wgpu::Texture` with an existing `egui::TextureId` while also accepting custom
+    /// `wgpu::SamplerDescriptor` options.
     ///
-    /// This enables applications to reuse `TextureId`s.
-    pub fn update_egui_texture_from_wgpu_texture(
+    /// This allows applications to reuse `TextureId`s created with custom sampler options.
+    pub fn update_egui_texture_from_wgpu_texture_with_sampler_options(
         &mut self,
         device: &wgpu::Device,
         texture: &wgpu::Texture,
-        texture_filter: wgpu::FilterMode,
+        sampler_descriptor: wgpu::SamplerDescriptor,
         id: egui::TextureId,
     ) -> Result<(), BackendError> {
         let id = match id {
@@ -557,10 +619,8 @@ impl RenderPass {
         })?;
 
         let sampler = device.create_sampler(&wgpu::SamplerDescriptor {
-            label: Some(format!("{}_texture_sampler", self.next_user_texture_id).as_str()),
-            mag_filter: texture_filter,
-            min_filter: texture_filter,
-            ..Default::default()
+            compare: None,
+            ..sampler_descriptor
         });
 
         // We've bound it here, so that we don't add it as a pending texture.
